/**
 * 小程序
 * 首页基础数据
 */

import * as partyMemberData from '../../data/partyMember';
import * as partyInformationData from '../../data/partyInformation';
import * as configEnum from "../../config/enum";
import * as clientConfigEnum from "../../config/clientEnum";
import * as splitResultConfig from "../../config/splitResultConfig";
import { extractData } from '../../util/piecemeal';
import { changeEnumValue, eccEnumValue } from '../../util/verificationEnum';
import { BizError } from '../../util/bizError';
import { ERRORENUM } from '../../config/errorEnum';
import { systemConfig } from '../../config/systemConfig';


/**
 * 主页基础数据
 * 小程序端 1.0
 * @param branchName 支部id
 * @returns {支部名称, 党员总数, 党建指令指数, 党内职务人员列表}
 */
export async function homeData(branchName) {
    if (branchName && branchName.length > 0) eccEnumValue("党建资讯列表查询", "支部名称", configEnum.BRANCHNAMETYPE, branchName);
    let branch = changeEnumValue(configEnum.BRANCHNAMETYPE, branchName); //支部名称
    let partyMemberNum = await partyMemberData.groupFindPartyMemberCount({branchName:{$in: branchName }}); //党员总数
    let massIndex = 87.6; //党建指令指数

    let partyPositions = []; //党内职务人员
    for (let key in clientConfigEnum.PARTYPOSITIONS) {
        let anyKey:any = key;
        if (isNaN(anyKey)) { //枚举key  key = string
            const EnumValue = parseInt(clientConfigEnum.PARTYPOSITIONS[key])
            let dataBaseList = await partyMemberData.getBaseListByPartyPositions( [EnumValue], [branchName] );
    
            let nameList = [];
            dataBaseList.forEach( info => {
                nameList.push(info.name);
            });

            if(nameList.length <= 0) nameList.push("暂无数据");

            partyPositions.push({
                key,
                list:nameList
            });

        }
        
    }

    return { branch, partyMemberNum, massIndex, partyPositions };
}


/**
 * 根据资讯类型查询党建资讯列表
 * 小程序端 1.0
 * @param informationType 党建资讯类型
 * @param branchName 支部id
 * @returns dataList:[返回字段参考splitResultConfig文件中的partyInformamtionConfig配置]
 */
export async function informationData(informationType:number, branchName) {
    if (informationType) eccEnumValue("党建资讯列表查询", "资讯类型", configEnum.INFORMATIONTYPE, informationType);
    if (branchName && branchName.length > 0) eccEnumValue("党建资讯列表查询", "支部名称", configEnum.BRANCHNAMETYPE, branchName);

    let partyInformationInfo = await partyInformationData.findPartyInformationListByType(informationType, branchName);
    if(!partyInformationInfo) throw new BizError(ERRORENUM.未找到数据, `库中不存在党建资讯类型为${informationType}, 支部为${branchName}的党建资讯列表`);

    let dataList = [];
    partyInformationInfo.forEach( info => {
        let changeData:any = extractData(splitResultConfig.partyInformationConfig, info, true);
        changeData.img = systemConfig.imgUrl + changeData.img;
        changeData.informationType = changeEnumValue(configEnum.INFORMATIONTYPE, changeData.informationType);
        changeData.branchName = changeEnumValue(configEnum.BRANCHNAMETYPE, changeData.branchName);
        dataList.push(changeData);
    })

    return dataList;
}



