/**
 * 小程序
 * 支部制度
 */

import * as branchSystemData from '../../../data/branchSystem';
import { extractData } from "../../../util/piecemeal";
import * as verificationEnumTools from "../../../util/verificationEnum";
import * as splitResultConfig from "../../../config/splitResultConfig";
import * as configEnum from "../../../config/enum";
import { eccFormParam } from '../../../util/verificationParam';
import * as eccFormParamConfig from "../../../config/eccFormParamConfig";
import moment = require('moment');


/**
 * 支部制度列表信息
 * 小程序端 2.0
 * @param systemTitle 制度标题
 * @param branchName 所属支部
 * @returns data:[返回字段参考splitResultConfig文件中的branchSystemConfig配置] 根据制度名称、所属支部 返回支部制度的列表
 */
 export async function getBranchSystem(systemTitle:string, branchName) {
    let selectParam = {};
    if (systemTitle) selectParam["systemTitle"] = systemTitle;
    selectParam["branchName"] = {$in: branchName};
    let branchSystemInfo = await branchSystemData.findBranchSystemList(selectParam);
    let data = [];
    /**截取返回字段 */
    branchSystemInfo.forEach (info => {
        let changeData:any = extractData(splitResultConfig.branchSystemConfig, info, true);

        data.push(changeData);
    })
    
    return data;
}


/**
 * 支部制度详细信息
 * 小程序端 2.0
 * @param bId 支部制度id
 * @returns changeData:[返回字段参考splitResultConfig文件中的branchSystemDetailsConfig配置] 根据支部制度id 返回支部制度的详细信息
 */
 export async function getBranchSystemDetsils(bId:number) {
    let branchSystemInfo = await branchSystemData.findBranchSystemById(bId);
    /**截取返回字段 */
    let changeData:any = extractData(splitResultConfig.branchSystemDetailsConfig, branchSystemInfo, true);
    if (changeData.branchName) changeData.branchName = verificationEnumTools.changeEnumValue(configEnum.BRANCHNAMETYPE, changeData.branchName);
    if (changeData.periodOfValidity) changeData.periodOfValidity = moment(changeData.periodOfValidity).format("YYYY-MM-DD");
    if (changeData.releaseTime) changeData.releaseTime = moment(changeData.releaseTime).format("YYYY-MM-DD");
    
    return changeData;
}


/**
 * 添加制度
 * 小程序端 2.0
 * @param branchName 支部名称
 * @param param 添加支部制度表单
 * 表单参数说明查看config/eccFormParamConfig文件里的CreateBranchSystemConfig配置
 * @returns {isSuccess: true} 是否创建成功
 */
export async function createBranchSystem(branchName, param) {
    /**校验表单参数 */
    eccFormParam("添加制度", eccFormParamConfig.CreateBranchSystemConfig, param);
    if (branchName && branchName.length > 0) verificationEnumTools.eccEnumValue("新增支部制度", "支部名称", configEnum.BRANCHNAMETYPE, branchName);
    param.branchName = branchName;

    await branchSystemData.createBranchSystem(param);

    return {isSuccess: true};
}