/**
 * 小程序
 * 党建先锋
 */

import * as partyVanguardData from '../../../data/partyVanguard';
import { checkChange, extractData } from "../../../util/piecemeal";
import * as verificationEnumTools from "../../../util/verificationEnum";
import * as splitResultConfig from "../../../config/splitResultConfig";
import * as configEnum from "../../../config/enum";
import { eccFormParam } from '../../../util/verificationParam';
import * as eccFormParamConfig from "../../../config/eccFormParamConfig";
import moment = require('moment');
import { ERRORENUM } from '../../../config/errorEnum';
import { BizError } from '../../../util/bizError';


/**
 * 党建先锋列表信息
 * 小程序端 2.0
 * @param honorName 荣誉名称
 * @param branchName 所属支部
 * @returns vanguardList:[返回字段参考splitResultConfig文件中的partyVanguardConfig配置] 根据荣誉名称、所属支部 返回党建先锋的荣誉列表
 */
 export async function getPartyVanguard(honorName:string, branchName) {
    let selectParam = {};
    
    // selectParam["honorName"] = honorName;
    
    if (honorName) {
        selectParam["honorName"] = {$in: honorName };
        let modelType = verificationEnumTools.changeEnumValue(configEnum.MODELTYPE, honorName);
        selectParam["modelType"] = {$in: modelType};
    }
    selectParam["branchName"] = {$in: branchName};
    let partyVanguardInfo = await partyVanguardData.findPartyVanguardeList(selectParam);
    let vanguardList = [];

    /**截取返回字段 */
    partyVanguardInfo.forEach (info => {
        let changeData:any = extractData(splitResultConfig.partyVanguardConfig, info, true);
        switch (changeData.honorType) {
            case 1:
                changeData.color = "#C62A23";

            break;
            case 2:
                changeData.color = "#E4B386";
            break;
        }
        if (info.honorLevel) changeData.honorLevel = verificationEnumTools.changeEnumValue(configEnum.HONORLEVEL, info.honorLevel);
        if (info.modelType) changeData.modelType = verificationEnumTools.changeEnumValue(configEnum.MODELTYPE, info.modelType);
        if (info.awardTime) changeData.awardTime = moment(info.awardTime).format("YYYY-MM-DD");
        if (info.grantTime) changeData.grantTime = moment(info.grantTime).format("YYYY-MM-DD");

        vanguardList.push(changeData);
    })
    
    return vanguardList;
}


/**
 * 党建先锋 荣誉详细信息
 * 小程序端 2.0
 * @param pvId 党建先锋id
 * @returns changeData:{返回字段参考splitResultConfig文件中的partyVanguardConfig配置} 根据id返回对应的荣誉详细信息
 */
 export async function getPartyVanguardDetsils(pvId:number) {
    let partyVanguardInfo = await partyVanguardData.findPartyVanguardById(pvId);
    let changeData:any = {};

    /**截取返回字段 */
    changeData = extractData(splitResultConfig.partyVanguardConfig, partyVanguardInfo, true);
    if (partyVanguardInfo.awardTime) changeData.awardTime = moment(partyVanguardInfo.awardTime).format("YYYY-MM-DD");
    if (partyVanguardInfo.grantTime) changeData.grantTime = moment(partyVanguardInfo.grantTime).format("YYYY-MM-DD");
    changeData.honorLevel = verificationEnumTools.changeEnumValue(configEnum.HONORLEVEL, partyVanguardInfo.honorLevel);
    
    return changeData;
}


/**
 * 党建先锋 新增支部先锋荣誉
 * 小程序端 2.0
 * @param param 新增党建支部先锋的支部先锋荣誉表单
 * 表单参数说明查看config/eccFormParamConfig文件里的CreateBranchPioneerConfig配置
 * @returns {isSuccess: true}
 */
 export async function createBranchPioneer(branchName, param) {
    /**校验表单参数 */
    eccFormParam("新增支部先锋荣誉", eccFormParamConfig.CreateBranchPioneerConfig, param)
    if (branchName && branchName.length > 0) verificationEnumTools.eccEnumValue("新增支部先锋荣誉", "支部名称", configEnum.BRANCHNAMETYPE, branchName);
    verificationEnumTools.eccEnumValue('新增支部先锋的荣誉级别类型', 'honorLevel', configEnum.HONORLEVEL, param.honorLevel);
    param.honorType = configEnum.HONORTYPE.支部先锋;
    param.branchName = branchName;

    await partyVanguardData.createPartyVanguard(param);

    return {isSuccess: true};
}


/**
 * 党建先锋 新建模范党员荣誉
 * 小程序端 2.0
 * @param param 新增党先锋的模范党员荣誉表单
 * 表单参数说明查看config/eccFormParamConfig文件里的CreateModelPartyConfig配置
 * @returns {isSuccess: true}
 */
 export async function createModelParty(branchName, param) {
    /**校验表单参数 */
    eccFormParam("新增模范党员荣誉", eccFormParamConfig.CreateModelPartyConfig, param)
    if (branchName && branchName.length > 0) verificationEnumTools.eccEnumValue("新增模范党员荣誉", "支部名称", configEnum.BRANCHNAMETYPE, branchName);
    verificationEnumTools.eccEnumValue('新增模范党员的模范类型', 'modelType', configEnum.MODELTYPE, param.modelType);
    param.honorType = configEnum.HONORTYPE.模范党员;
    param.branchName = branchName;
    
    await partyVanguardData.createPartyVanguard(param);

    return {isSuccess: true};
}


/**
 * 党建先锋 修改党建先锋荣誉
 * 小程序端 2.0
 * @param pvId 党建先锋id 修改对应pvId的荣誉信息
 * @param honorType 荣誉类型
 * @param param 修改党建先锋表单 
 * 荣誉类型为支部先锋 表单参数依据config/eccFormParamConfig文件里的UpdateBranchPioneerConfig配置
 * 荣誉类型为模范党员 表单参数依据config/eccFormParamConfig文件里的UpdateModelPartyConfig配置
 * @returns {isSuccess:true}
 */
export async function updatePartyVanguard(pvId:number, honorType:number, param) {
    /**校验表单参数 */
    if (honorType == configEnum.HONORTYPE.支部先锋) {
        eccFormParam("党建先锋荣誉表单修改", eccFormParamConfig.UpdateBranchPioneerConfig, param );
        verificationEnumTools.eccEnumValue('修改党建先锋的支部先锋', 'honorLevel', configEnum.HONORLEVEL, param.honorLevel);
    } else if (honorType == configEnum.HONORTYPE.模范党员) {
        eccFormParam("党建先锋荣誉表单修改", eccFormParamConfig.UpdateModelPartyConfig, param );
        verificationEnumTools.eccEnumValue('修改党建先锋的模范党员', 'modelType', configEnum.MODELTYPE, param.modelType);
    }
    
    let partyVanguardInfo = await partyVanguardData.findPartyVanguardById(pvId);
    if (!partyVanguardInfo) throw new BizError(ERRORENUM.未找到数据, `库中不存在id为${pvId}荣誉信息`);
    
    let changeList = checkChange(param, partyVanguardInfo);
    if ( !changeList.length ) throw new BizError(ERRORENUM.数据无更新, `${pvId}数据无更新`);

    changeList.forEach(key => {
        partyVanguardInfo[key] = param[key];
    });

    await partyVanguardInfo.save();

    return {isSuccess:true};
}


/**
 * 删除荣誉
 * 小程序端 2.0
 * @param pvId 荣誉id
 * @returns {isSuccess:true}
 */
 export async function deletePartyVanguard(pvId:number) {
    let partyVanguardInfo = await partyVanguardData.findPartyVanguardById(pvId);
    if (!partyVanguardInfo) throw new BizError(ERRORENUM.未找到数据, `库中不存在id为${pvId}荣誉信息`);

    await partyVanguardData.deletePartyVanguard(pvId);

    return {isSuccess:true};
}

