/**
 * 支部制度表
 */

import { Schema } from "mongoose";
import {yfsDB} from '../db/dbInit';
var autoIncrement = require('mongoose-auto-increment');

const branchSystemSchema = new Schema({
    bId: {type:Number, index:{unique: true}}, //自增的支部制度id
    systemTitle: String, //制度标题
    periodOfValidity: Number, //制度有效期
    releaseTime: Number, //发布时间
    systemContent: String, //制度内容
    branchName: {type:[Number], default:[]}, //支部名称
})

var branchSystemModel;

export function initModel(){
    branchSystemSchema.plugin(autoIncrement.plugin, {
        model: 'branchSystemSchema',
        field: 'bId',
        startAt: 1, //初始化id从1开始
        incrementBy: 1 //每次自增1
    });

    branchSystemModel = yfsDB.model('branchSystem', branchSystemSchema);
    branchSystemModel.selectOnceData = async function (paramater:object) {
        let selectInfo = await branchSystemModel.findOne(paramater).exec();
        if (selectInfo) {
            if (!selectInfo.runSave) {
                selectInfo.runSave = selectInfo.save;
                selectInfo.save = save.bind(selectInfo)
            }
        }

        return selectInfo;
    }
}


export async function save(throwError=false) {
    if (!this.isModified()) return;
    await this.runSave({validateBeforeSave:false}).catch(err=>{
        console.log(err);
    });
}


/**
 * 获取符合条件的支部制度列表
 * @param param 查询参数
 * @returns 
 */
export async function findBranchSystemList(param:object) {
    return await branchSystemModel.find(param);
} 


/**
 * 新增 支部制度
 * @param param 所添加表单 需要提前验证
 */
 export async function createBranchSystem(param:object) {
    return await branchSystemModel.create(param);
}


/**
 * 获取符合条件的支部制度数量
 * @param param 查询参数
 * @returns number 数据数量
 */
 export async function groupFindBranchSystemCount(param:object) {
    return await branchSystemModel.find(param).countDocuments();
}


/**
 * 根据id获取符合条件的支部制度
 * @param param 查询参数
 * @returns 
 */
 export async function findBranchSystemById(bId:number) {
    return await branchSystemModel.findOne({bId});
} 
