/**
 * 党建先锋表
 */

import { Schema } from "mongoose";
import {yfsDB} from '../db/dbInit';
var autoIncrement = require('mongoose-auto-increment');

const partyVanguardSchema = new Schema({
    pvId: {type:Number, index:{unique: true}}, //自增的党建先锋id
    honorType: Number, //荣誉类型 1：支部先锋、2：模范党员
    honorLevel: Number, //荣誉级别 1：区级荣誉、2：市级荣誉、3：院级荣誉、4：国家级荣誉
    honorName: String, //荣誉名称
    grantingUnit:String, //授予单位
    awardTime: Number, //获奖时间
    honorsIntroduction: String, //荣誉简介
    modelType: Number,//模范类型 
    grantParty: {type:[String], default:[]},//授予党员
    grantTime: Number,//授予时间
    grantReason: String,//授予原因
    branchName: {type:[Number], default:[]}, //支部名称
})

var partyVanguardModel;

export function initModel(){
    partyVanguardSchema.plugin(autoIncrement.plugin, {
        model: 'partyVanguardSchema',
        field: 'pvId',
        startAt: 1, //初始化id从1开始
        incrementBy: 1 //每次自增1
    });

    partyVanguardModel = yfsDB.model('partyVanguard', partyVanguardSchema);
    partyVanguardModel.selectOnceData = async function (paramater:object) {
        let selectInfo = await partyVanguardModel.findOne(paramater).exec();
        if (selectInfo) {
            if (!selectInfo.runSave) {
                selectInfo.runSave = selectInfo.save;
                selectInfo.save = save.bind(selectInfo)
            }
        }

        return selectInfo;
    }
}


export async function save(throwError=false) {
    if (!this.isModified()) return;
    await this.runSave({validateBeforeSave:false}).catch(err=>{
        console.log(err);
    });
}
 

/**
 * 获取符合条件的党建先锋列表
 * @param param 查询参数
 * @returns 
 */
export async function findPartyVanguardeList(param:object) {
    return await partyVanguardModel.find(param);
} 


/**
 * 获取符合条件的党员数量
 * @param param 查询参数
 * @returns number 数据数量
 */
 export async function groupFindPartyVanguardCount(param:object) {
    return await partyVanguardModel.find(param).countDocuments();
}


/**
 * 新增 支部先锋，模范党员
 * @param param 所添加表单 需要提前验证
 */
export async function createPartyVanguard(param:object) {
    return await partyVanguardModel.create(param);
}


/**
  * 删除组织生活活动
  * @param oId 活动id
  * @returns 
  */
export async function deletePartyVanguard(pvId:number) {
    return await partyVanguardModel.deleteOne({pvId}).exec();
}



/**
 * 根据id获取党建先锋详情
 * @param pvId 党建先锋id
 * @returns 
 */
 export async function findPartyVanguardById(pvId:number) {
    return await partyVanguardModel.findOne({pvId});
} 



 