/**
 * 小程序端 党员入口 党建先锋
 */

import * as partyVanguardBiz from '../../biz/applet/partyMember/partyVanguard';
import * as asyncHandler from 'express-async-handler';
import { eccReqParamater } from '../../util/verificationParam';
import { checkAppletToken } from '../../middleware/user';

export function setRouter(httpServer) {
  httpServer.post('/partymember/partyvanguard/list', checkAppletToken, asyncHandler(getPartyVanguard));
  httpServer.post('/partymember/partyvanguard/detsils', checkAppletToken, asyncHandler(getPartyVanguardDetsils));
  httpServer.post('/partymember/partyvanguard/createbranchpioneer', checkAppletToken, asyncHandler(createBranchPioneer));
  httpServer.post('/partymember/partyvanguard/createmodelparty', checkAppletToken, asyncHandler(createModelParty));
  httpServer.post('/partymember/partyvanguard/update', checkAppletToken, asyncHandler(updatePartyVanguard));
  httpServer.post('/partymember/partyvanguard/delete', checkAppletToken, asyncHandler(deletePartyVanguard));
}


 /**  
  * 党建先锋 荣誉列表
  * @param req 
  * @param res 
  */
async function getPartyVanguard(req, res) {
  let reqConf = {honorName:'String'};
  let {honorName} = eccReqParamater(reqConf, req.body, ["honorName"]);

  let branchidData = req.headers.branchid;
  let branchName = [];
  branchidData = branchidData.slice(1, branchidData.length-1);
  branchName = branchidData.split(',');

  let result = await partyVanguardBiz.getPartyVanguard(honorName, branchName);
  res.success(result);
}


/**
 * 党建先锋 获取荣誉详情
 * @param req 
 * @param res 
 */
async function getPartyVanguardDetsils(req, res) {
  let reqConf = {pvId:'Number'};
  let {pvId} = eccReqParamater(reqConf, req.body);

  let result = await partyVanguardBiz.getPartyVanguardDetsils(pvId);
  res.success(result);
}


/**
 * 党建先锋 新增支部先锋荣誉
 * @param req 
 * @param res 
 */
async function createBranchPioneer(req, res) {
  let reqConf = {form: 'Object' };
  let { form } = eccReqParamater(reqConf, req.body);
  
  let branchidData = req.headers.branchid;
  let branchName = [];
  branchidData = branchidData.slice(1, branchidData.length-1);
  branchName = branchidData.split(',');
  
  let result = await partyVanguardBiz.createBranchPioneer(branchName, form);
  res.success(result);
};


/**
 * 党建先锋 新增模范党员荣誉
 * @param req 
 * @param res 
 */
async function createModelParty(req, res) {
  let reqConf = {form: 'Object' };
  let { form } = eccReqParamater(reqConf, req.body);
  
  let branchidData = req.headers.branchid;
  let branchName = [];
  branchidData = branchidData.slice(1, branchidData.length-1);
  branchName = branchidData.split(',');

  let result = await partyVanguardBiz.createModelParty(branchName, form);
  res.success(result);
};


/**
 * 党建先锋 修改荣誉详细
 * @param req 
 * @param res 
 */
async function updatePartyVanguard(req, res) {
  let reqConf = {pvId: 'Number', honorType: 'Number', form: 'Object' };
  let { pvId, honorType, form } = eccReqParamater(reqConf, req.body);

  let result = await partyVanguardBiz.updatePartyVanguard(pvId, honorType, form);
  res.success(result);
}


/**
 * 党建先锋 删除党建先锋荣誉数据
 * @param req 
 * @param res 
 */
async function deletePartyVanguard(req, res) {
  let reqConf = {pvId: 'Number'};
  let {pvId} = eccReqParamater(reqConf, req.body);

  let result = await partyVanguardBiz.deletePartyVanguard(pvId);
  res.success(result);
}