/**
 * 公共资源路由
 */

import * as asyncHandler from 'express-async-handler';
import * as configEnum from "../config/enum";
import * as clientConfigEnum from "../config/clientEnum";

export function setRouter(httpServer) {
    httpServer.post('/public/partypositions', asyncHandler(partyPositions));
    httpServer.post('/public/type', asyncHandler(type));
    httpServer.post('/public/entrytype', asyncHandler(entryType));
    httpServer.post('/public/activitytype', asyncHandler(activityType));
    httpServer.post('/public/informationtype', asyncHandler(informationType));
    httpServer.post('/public/sex', asyncHandler(sexType));
    httpServer.post('/public/degree', asyncHandler(degreeType));
    httpServer.post('/public/administrativeposition', asyncHandler(administrativePosition));
    httpServer.post('/public/department', asyncHandler(department));
    httpServer.post('/public/degreetype', asyncHandler(degreeType));
    httpServer.post('/public/honortype', asyncHandler(honorType));
    httpServer.post('/public/honorlevel', asyncHandler(honorLevel));
    httpServer.post('/public/modeltype', asyncHandler(modelType));
}


/**
 * 党内职务
 * @param req  
 * @param res 
 */
function partyPositions(req, res) {
    let dataList = getEnumList(configEnum.PARTYPOSITIONS);
    res.success(dataList);
}


/**
 * 组织生活活动类型
 * @param req  
 * @param res 
 */
 function type(req, res) {
    let dataList = getEnumList(clientConfigEnum.TYPE);
    res.success(dataList);
}


/**
 * 名册录入类型
 * @param req  
 * @param res 
 */
 function entryType(req, res) {
    let dataList = getEnumList(clientConfigEnum.ENTRYTYPE);
    res.success(dataList);
}


/**
 * 党建活动类型
 * @param req  
 * @param res 
 */
 function activityType(req, res) {
    let dataList = getEnumList(configEnum.ACTIVITYTYPE);
    res.success(dataList);
}


/**
 * 党建资讯类型
 * @param req  
 * @param res 
 */
 function informationType(req, res) {
    let dataList = getEnumList(configEnum.INFORMATIONTYPE);
    res.success(dataList);
}


/**
 * 性别类型
 * @param req 
 * @param res 
 */
function sexType(req, res) {
    let dataList = getEnumList(configEnum.SEX);
    res.success(dataList);
}


/**
 * 文化程度类型
 * @param req 
 * @param res 
 */
function degreeType(req, res) {
    let dataList = getEnumList(configEnum.DEGREE);
    res.success(dataList);
}


/**
 * 行政职务类型
 * @param req 
 * @param res 
 */
function administrativePosition(req, res) {
    let dataList = getEnumList(configEnum.ADMINISTRATIVEPOSITION);
    res.success(dataList);
}


/**
 * 所属科室类型
 * @param req 
 * @param res 
 */
function department(req, res) {
    let dataList = getEnumList(configEnum.DEDPARTMENT);
    res.success(dataList);
}


/**
 * 荣誉类型
 * @param req 
 * @param res 
 */
function honorType(req, res) {
    let dataList = getEnumList(configEnum.HONORTYPE);
    res.success(dataList);
}


/**
 * 荣誉级别
 * @param req 
 * @param res 
 */
function honorLevel(req, res) {
    let dataList = getEnumList(configEnum.HONORLEVEL);
    res.success(dataList);
}


/**
 * 模范类型
 * @param req 
 * @param res 
 */
function modelType(req, res) {
    let dataList = getEnumList(configEnum.MODELTYPE);
    res.success(dataList);
}


function getEnumList(enumData) {
    let dataList= [];
    for (let key in enumData) {
        let anyKey:any = key;
        if (isNaN(anyKey)) {
            let keyStr = key;
            dataList.push({key:keyStr, value:enumData[key]});
        }
    }

    return dataList;
}