import { createPartyMember, groupFindPartyMemberCount } from "../data/partyMember";
import * as enums from "../config/enum";
import { getPwdMd5 } from "./system";
import { createActivity, groupFindActivityCount } from "../data/organizationalLife";
import { createPartyVanguard, groupFindPartyVanguardCount } from "../data/partyVanguard";
import { createBranchSystem, groupFindBranchSystemCount } from "../data/branchSystem";
import { createPartyInformation, groupFindpartyInformationCount } from "../data/partyInformation";

const xlsx = require('node-xlsx');
const path = require('path');
const md5 = require("md5");


const PartyPositionsChangeConfig = {
    "党员": enums.PARTYPOSITIONSICON.党员,
    "入党积极分子": enums.PARTYPOSITIONSICON.入党积极分子,
    "预备党员": enums.PARTYPOSITIONSICON.预备党员,
    "党总支书记": enums.PARTYPOSITIONSICON.党总支书记,
    "党总支副书记": enums.PARTYPOSITIONSICON.党总支副书记,
    "党总支宣传委员":enums.PARTYPOSITIONSICON.党总支宣传委员,
    "党总支统战委员":enums.PARTYPOSITIONSICON.党总支统战委员,
    "党总支纪检委员":enums.PARTYPOSITIONSICON.党总支纪检委员,
    "支部书记":enums.PARTYPOSITIONSICON.支部书记,
    "支部副书记":enums.PARTYPOSITIONSICON.支部副书记,
    "纪检委员":enums.PARTYPOSITIONSICON.纪检委员,
    "统战委员":enums.PARTYPOSITIONSICON.统战委员,
    "组织委员":enums.PARTYPOSITIONSICON.组织委员,
    "宣传委员":enums.PARTYPOSITIONSICON.宣传委员,
}

const BranchNameChangeConfig = {
    "党总支": enums.BRANCHNAMETYPE.党总支,
    "牙防所第一支部": enums.BRANCHNAMETYPE.牙防所第一支部,
    "牙防所第二支部": enums.BRANCHNAMETYPE.牙防所第二支部,
    "牙防所第三支部": enums.BRANCHNAMETYPE.牙防所第三支部,
    "牙防所第四支部": enums.BRANCHNAMETYPE.牙防所第四支部,
}

const DepartmentConfig = {
    "办公室": enums.DEDPARTMENT.办公室,
    "财务科": enums.DEDPARTMENT.财务科,
    "放射科": enums.DEDPARTMENT.放射科,
    "工会": enums.DEDPARTMENT.工会,
    "技术室": enums.DEDPARTMENT.技术室,
    "颌面外科": enums.DEDPARTMENT.颌面外科,
    "护理": enums.DEDPARTMENT.护理,
    "护理部": enums.DEDPARTMENT.护理部,
    "检验科": enums.DEDPARTMENT.检验科,
    "康健分所": enums.DEDPARTMENT.康健分所,
    "科教科": enums.DEDPARTMENT.科教科,
    "口腔颌面外科": enums.DEDPARTMENT.口腔颌面外科,
    "口腔科": enums.DEDPARTMENT.口腔科,
    "口腔修复科": enums.DEDPARTMENT.口腔修复科,
    "口腔正畸科": enums.DEDPARTMENT.口腔正畸科,
    "口腔综合科": enums.DEDPARTMENT.口腔综合科,
    "人事科": enums.DEDPARTMENT.人事科,
    "特需": enums.DEDPARTMENT.特需,
    "信息科": enums.DEDPARTMENT.信息科,
    "修复科": enums.DEDPARTMENT.修复科,
    "牙体牙髓科": enums.DEDPARTMENT.牙体牙髓科,
    "牙周科": enums.DEDPARTMENT.牙周科,
    "药房": enums.DEDPARTMENT.药房,
    "医务科": enums.DEDPARTMENT.医务科,
    "预防科": enums.DEDPARTMENT.预防科,
    "预防口腔": enums.DEDPARTMENT.预防口腔,
    "儿童口腔科": enums.DEDPARTMENT.儿童口腔科,
    "院部": enums.DEDPARTMENT.院部,
    "种植科": enums.DEDPARTMENT.种植科,
    "正畸科": enums.DEDPARTMENT.正畸科,
    "综合科": enums.DEDPARTMENT.综合科,
}

export async function initBasicData() {
    await initPartyMember();
    await initOrganizationalLife();
    await initPartyVanguard();
    await initBranchSystem();
    await initInforMation();
}


/**
 * 党员基础信息初始化
 */
async function initPartyMember() {
    let count = await groupFindPartyMemberCount({});
    if (count > 5) {
        console.log("***** 党员基础信息数据 无需初始化 *****");
        return;
    }

    let {sheetMap} = getExcel(path.join(__dirname.substring(0, __dirname.indexOf("out")), "res", "牙防所基础数据收集.xlsx"));

    let dataList = sheetMap["党员信息"];
    let titleMap = {
        "0": "name", //姓名
        "1": "sex", //性别
        "2": "birthDate", //出生时间
        "3": "phone", //手机号码
        "4": "levelOfEducation", //文化程度
        "5": "partyJoiningTime", //入党时间
        "6": "administrativePosition", //行政职务
        "7": "remarks", //备注
        "8": "entryType", //名册录入类型
        "9": "partyPositions", //党内职务
        "10": "listedAsActivistsTime", //列为积极份子时间（入党积极份子填写）
        "11": "askForTime", //申请入党时间（入党申请填写）
        "12": "talkTime", //谈话时间（入党申请填写）
        "13": "branchName", //支部名称
        "14": "department", //所属科室
        "15": "partyState", //党员状态
    }

    let utc = new Date();
    let addList = [];
    dataList.forEach( (subList, index) => {
        if (!index) return; //跳过表头
        let addDataInfo:any = {
            firstLoginIsChangePwd:false,
        }

        for (let i = 0; i <= 15; i++) {
            let item =subList[i];
            let key = titleMap[i];
            let value = item;
            if (i == 1) {
                value = enums.SEX[item] || 0;
            }
            if (i == 2 && item) {
                value = new Date(item).valueOf();
            }
            if (i ==3) {
                let itemStr = `${item}`;
                if(!addDataInfo.pwd) addDataInfo.pwd = getPwdMd5(itemStr, md5(itemStr.slice(itemStr.length-6)));
                else addDataInfo.pwd = getPwdMd5(itemStr, addDataInfo.pwd);
                addDataInfo.loginId = itemStr;
            }
            if (i == 4) {
                value = enums.DEGREE[item] || 1;
            }
            if (i == 5 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 6) {
                value = enums.ADMINISTRATIVEPOSITION[item] || 0;
            }
            if (i == 8) {
                value = enums.ENTRYTYPE[item] || 1;
            }
            if (i == 9) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        let valueNum = PartyPositionsChangeConfig[oldStr.trim()];
                        if (valueNum) value.push(valueNum);
                    });
                };
                
            }
            if (i == 10 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 11 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 12 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 13) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        let valueNum = BranchNameChangeConfig[oldStr.trim()];
                        if (valueNum) value.push(valueNum);
                    });
                };
            }
            if (i == 14) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        let valueNum = DepartmentConfig[oldStr.trim()];
                        if (valueNum) value.push(valueNum);
                    });
                };
                
            }
            if (i == 15) {
                value = enums.PARTYSTATE[item] || 0;
            }
            addDataInfo[key] = value;
        }
        addList.push(addDataInfo);
    })
    
    await createPartyMember(addList);
    console.log("---> 党员基础信息 初始化成功");
}


const HonorLevelConfig = {
    "区级荣誉": enums.HONORLEVEL.区级荣誉,
    "市级荣誉": enums.HONORLEVEL.市级荣誉,
}

/**
 * 党建先锋初始化
 */
async function initPartyVanguard() {
    let count = await groupFindPartyVanguardCount({});
    if (count >= 1) {
        console.log("***** 党建先锋数据 无需初始化 *****");
        return;
    }

    let {sheetMap} = getExcel(path.join(__dirname.substring(0, __dirname.indexOf("out")), "res", "牙防所基础数据收集.xlsx"));
    let dataList = sheetMap["党建先锋"];

    let titleMap = {
        "0": "honorType", //荣誉类型
        "1": "honorLevel", //荣誉级别
        "2": "honorName", //荣誉名称
        "3": "grantingUnit", //授予单位
        "4": "awardTime", //获奖时间
        "5": "honorsIntroduction", //荣誉简介
        "6": "modelType", //模范类型
        "7": "grantParty", //授予党员
        "8": "grantTime", //授予时间
        "9": "grantReason", //授予原因
        "10": "branchName", //支部名称
    };

    let addList = [];
    dataList.forEach( (subList, index) => {
        if (!index) return; //跳过表头
        let addDataInfo:any = {
            firstLoginIsChangePwd:false,
        }

        for (let i = 0; i <= 10; i++) {
            let item =subList[i];
            let key = titleMap[i];
            let value = item;
            if (i == 0) {
                value = enums.HONORTYPE[item] || 0;
            }
            if (i == 1) {
                value = enums.HONORLEVEL[item] || 0;
            }
            if (i == 4 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 6) {
                value = enums.MODELTYPE[item] || 0;
            }
            if (i == 7) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        if (oldStr) value.push(oldStr);
                    });
                };
            }
            if (i == 8 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 10) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        let valueNum = BranchNameChangeConfig[oldStr.trim()];
                        if (valueNum) value.push(valueNum);
                    });
                };
            }
            if (value) addDataInfo[key] = value;
        }
        addList.push(addDataInfo);
    })
    
    await createPartyVanguard(addList);
    console.log("---> 党建先锋信息 初始化成功");
}


/**
 * 组织生活初始化
 */
async function initOrganizationalLife() {
    let count = await groupFindActivityCount({});
    if (count >= 1) {
        console.log("***** 组织生活数据 无需初始化 *****");
        return;
    }
    
    let {sheetMap} = getExcel(path.join(__dirname.substring(0, __dirname.indexOf("out")), "res", "牙防所基础数据收集.xlsx"));
    let dataList = sheetMap["组织生活"];

    let titleMap = {
        "0": "partyActivityType", //党建活动类型
        "1": "activityStartTime", //活动开始时间
        "2": "activityEndTime", //活动结束时间
        "3": "activityAdd", //活动地点
        "4": "activityHost", //活动主持人
        "5": "activityNoteTaker", //活动记录人
        "6": "leavePartyMember", //请假党员
        "7": "participatingPartyMember", //参与党员
        "8": "participationRecord", //活动记录
        "9": "branchName", //支部名称
    };

    let addList = [];
    dataList.forEach( (subList, index) => {
        if (!index) return; //跳过表头
        let addDataInfo:any = {
            firstLoginIsChangePwd:false,
        }

        for (let i = 0; i <= 9; i++) {
            let item =subList[i];
            let key = titleMap[i];
            let value = item;
            if (i == 0) {
                value = enums.ACTIVITYTYPE[item] || 1;
            }
            if (i == 1 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 2 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 4) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        // let valueNum = HonorLevelConfig[oldStr.trim()];
                        if (oldStr) value.push(oldStr);
                    });
                };
            }
            if (i == 5) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        // let valueNum = HonorLevelConfig[oldStr.trim()];
                        if (oldStr) value.push(oldStr);
                    });
                };
            }
            if (i == 6) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        // let valueNum = HonorLevelConfig[oldStr.trim()];
                        if (oldStr) value.push(oldStr);
                    });
                };
            }
            if (i == 7) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        // let valueNum = HonorLevelConfig[oldStr.trim()];
                        if (oldStr) value.push(oldStr);
                    });
                };
            }
            if (i == 9) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        let valueNum = BranchNameChangeConfig[oldStr.trim()];
                        if (valueNum) value.push(valueNum);
                    });
                };
            }
            if (value) addDataInfo[key] = value;
        }
        addList.push(addDataInfo);
    })
    
    await createActivity(addList);
    console.log("---> 组织生活信息 初始化成功");
}


/**
 * 支部制度初始化
 */
async function initBranchSystem() {
    let count = await groupFindBranchSystemCount({});
    if (count >= 1) {
        console.log("***** 支部制度数据 无需初始化 *****");
        return;
    }

    let {sheetMap} = getExcel(path.join(__dirname.substring(0, __dirname.indexOf("out")), "res", "牙防所基础数据收集.xlsx"));
    let dataList = sheetMap["支部制度"];

    let titleMap = {
        "0": "systemTitle", //制度标题
        "1": "periodOfValidity", //制度有效期
        "2": "releaseTime", //发布时间
        "3": "systemContent", //制度内容
        "4": "branchName", //支部名称
    };

    let addList = [];
    dataList.forEach( (subList, index) => {
        if (!index) return; //跳过表头
        let addDataInfo:any = {
            firstLoginIsChangePwd:false,
        }

        for (let i = 0; i <= 4; i++) {
            let item =subList[i];
            let key = titleMap[i];
            let value = item;
            if (i == 1 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 2 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 4) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        let valueNum = BranchNameChangeConfig[oldStr.trim()];
                        if (valueNum) value.push(valueNum);
                    });
                };
            }

            if (value) addDataInfo[key] = value;
        }
        addList.push(addDataInfo);
    })
    
    await createBranchSystem(addList);
    console.log("---> 支部制度信息 初始化成功");
}


/**
 * 党建资讯
 */
async function initInforMation() {
    let count = await groupFindpartyInformationCount({});
    if (count >= 1) {
        console.log("***** 党建资讯数据 无需初始化 *****");
        return;
    }

    let {sheetMap} = getExcel(path.join(__dirname.substring(0, __dirname.indexOf("out")), "res", "牙防所基础数据收集.xlsx"));
    let dataList = sheetMap["党建资讯"];

    let titleMap = {
        "0": "informationType", //党建资讯类型
        "1": "title", //资讯列表
        "2": "informationTime", //资讯时间
        "3": "detailedInformation", //资讯详细
        "4": "img", //图片
        "5": "branchName", //支部名称
    };

    let addList = [];
    dataList.forEach( (subList, index) => {
        if (!index) return; //跳过表头
        let addDataInfo:any = {
            firstLoginIsChangePwd:false,
        }

        for (let i = 0; i <= 5; i++) {
            let item =subList[i];
            let key = titleMap[i];
            let value = item;
            if (i == 0) {
                value = enums.INFORMATIONTYPE[item] || 0;
            }
            if (i == 2 && item) {
                value = new Date(item).valueOf();
            }
            if (i == 5) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        let valueNum = BranchNameChangeConfig[oldStr.trim()];
                        if (valueNum) value.push(valueNum);
                    });
                };
            }

            if (value) addDataInfo[key] = value;
        }
        addList.push(addDataInfo);
    })
    
    await createPartyInformation(addList);
    console.log("---> 党建资讯信息 初始化成功");
}


/**
 * 获取单个excel文件数据
 * @param filePath 
 * @returns 
 */
 function getExcel(filePath) {
    const workSheetsFromFile = xlsx.parse(filePath);
    let sheetMap = {};
    let sheetList = [];

    for (let i = 0; i < workSheetsFromFile.length; i++) {
        let sheetInfo = workSheetsFromFile[i];
        sheetMap[sheetInfo.name] = sheetInfo.data;
        sheetList.push(sheetInfo);
    }

    return {sheetMap, sheetList}  
}